# auto-rxn

Python package for running chemical reactions as defined by "recipe" files.

## original design

Credit for original design of this interface goes to Unni Kurumbail of the Herman's Group at University of Wisconsin-Madison Chemistry Department.

<https://github.com/ukurumbail/auto_rxn>

## enabling technologies

Auto-rxn relies on a host of larger open-source software projects, highlighted here.

[Bluesky](https://blueskyproject.io/bluesky/), a Python library for experimental orchestration.

[HAPPI](https://pcdshub.github.io/happi/), a database for access to hardware interfaces.

[yaq](https://yaq.fyi/), a modular and extensible instrument control framework.

The large scientific python ecosystem, especially [NumPy](https://numpy.org/), [pandas](https://pandas.pydata.org/), and [Matplotlib](https://matplotlib.org/). ❤️

